#!/usr/bin/env python
#-*- coding:utf-8 -*-
import os
from PySide6.QtQml import QQmlApplicationEngine

def init(engine:QQmlApplicationEngine):
    current_module_path = os.path.dirname(os.path.abspath(__file__))+"/qml"
    print("FluentUI plugin dir ->"+current_module_path+"/FluentUI")
    engine.addImportPath(current_module_path)
    


import setuptools

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name = "PySide6-FluentUI-QML",
    version = "1.6.6",
    keywords="pyside fluent qml",
    author="ZhuZiChu",
    author_email="zhuzichu520@outlook.com",
    description="A fluent design qml library based on PySide6",
    long_description=long_description,
    long_description_content_type='text/markdown',
    license="MIT",
    url="https://github.com/zhuzichu520/FluentUI",
    packages=setuptools.find_namespace_packages(
                     include=["FluentUI", "FluentUI.*"], ),
    include_package_data=True,
    install_requires=[
        "PySide6>=6.6.1"
    ],
    classifiers=[
        'Programming Language :: Python :: 3'
    ]
)
